@@ -3,7 +3,8 @@ use File::Next ();
 use App::Ack ();
 
 sub prep_environment {
-    delete @ENV{qw( ACK_OPTIONS ACKRC ACK_PAGER )};
+    delete @ENV{qw( ACK_OPTIONS ACK_PAGER )};
+    $ENV{ACKRC} = 't/ackrc-empty';
 }
 
 # capture stderr output into this file
